ConditionKeyword class sealed
unit symbol に対して 空文字かどうかを判定するための keyword.
- Inheritance
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ Map<
String, Object> -
inactivate(), = operator, [] operator, など に依存されている.
no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
ここでの toJson とは json へ encode 可能な形式へ変換するという意味で使われる.
つまり json string を返すというわけではない.
また serialize としても利用するため deserialize 可能でなければならない.
inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → Danger< ConditionKeyword, EnumPatternExceptionA> -
override
Constants
-
INSTANCE_SET
→ const Set<
ConditionKeyword> -
VALUE_SET
→ const Set<
String>